@@ -13,14 +13,32 @@ Furthermore we cannot accumulate all results and then process them, because it w
 impossible to launch lang scrape jobs with millions of keywords.
 """
 
+output_format = 'stdout'
 outfile = None
+wrote_json_start = False
+
+class JsonStreamWriter():
+    """Writes consecutive objects to an json output file."""
+
+    def __init__(self, filename):
+        self.file = open(filename, 'wt')
+        self.file.write('[')
+
+    def write(self, obj):
+        json.dump(obj, self.file, indent=2, sort_keys=True, ensure_ascii=True)
+        self.file.write(',')
+
+    def __del__(self):
+        self.file.write(']')
+
 
 def init_output_storage():
     """Init an outfile."""
-    global outfile
+    global outfile, output_format
 
-    output_format = Config['GLOBAL'].get('output_format', 'stdout')
-    output_file = Config['GLOBAL'].get('output_filename', 'google_scraper')
+    output_file = Config['OUTPUT'].get('output_filename')
+    if '.' in output_file:
+        output_format = output_file.split('.')[-1]
 
     if not outfile:
         # the output files. Either CSV or JSON or STDOUT
@@ -28,31 +46,28 @@ def init_output_storage():
         # create the array of the most outer results ourselves because we write
         # results as soon as we get them (it's impossible to hold the whole search in memory).
         if output_format == 'json':
-            outfile = open(output_file + '.json', 'a')
-            outfile.write('[')
+            outfile = JsonStreamWriter(output_file)
         elif output_format == 'csv':
-            outfile = csv.DictWriter(open(output_file + '.csv', 'a'),
-                    fieldnames=('link', 'title', 'snippet', 'visible_link', 'num_results',
+            outfile = csv.DictWriter(open(output_file, 'wt'),
+                    fieldnames=('rank', 'link', 'title', 'snippet', 'visible_link', 'num_results',
                                 'query', 'search_engine_name', 'requested_by',
                                 'scrapemethod', 'page_number', 'requested_at'))
             outfile.writeheader()
         elif output_format == 'stdout':
             outfile = sys.stdout
 
-def store_serp_result(obj, serp, parser=None):
+def store_serp_result(obj, serps=None, parser=None):
     """Store the parsed SERP page in the suited output format.
 
-    If there is no parser object, the links are available over
-    serp.links
+    If there is no parser object given, the links are available over
+    serp.links.
 
     Args:
         obj: The serp object as dict.
         serp: The serp object
         parser: A parse object.
     """
-    global outfile
-
-    output_format = Config['GLOBAL'].get('output_format', 'stdout')
+    global outfile, output_format
 
     if not outfile:
         init_output_storage()
@@ -65,27 +80,40 @@ def store_serp_result(obj, serp, parser=None):
                     if isinstance(value, list):
                         for link in value:
                             rows.append(link)
-            else:
-                for link in serp.links:
-                    row.append(link)
             return rows
-
         if output_format == 'json':
-            obj['results'] = results()
-            json.dump(obj, outfile, indent=2, sort_keys=True)
-            outfile.write(',')
+            # The problem here is, that we need to stream write the json data.
+
+            if parser:
+                if not obj:
+                    obj = {}
+                obj['results'] = results()
+            elif serps:
+                for serp in serps:
+                    data = {}
+                    data.update(dict_from_serp_object(serp))
+                    data['results'] = []
+                    for link in serp.links:
+                        d = row2dict(link)
+                        data['results'].append(d)
+                    outfile.write(data)
+
+            elif parser:
+                outfile.write(obj)
         elif output_format == 'csv':
-            for row in results():
-                row.update(obj)
-                outfile.writerow(row)
+            if parser:
+                for row in results():
+                    row.update(obj)
+                    outfile.writerow(row)
+
         elif output_format == 'stdout' and Config['GLOBAL'].getint('verbosity', 1) > 2:
-            print(parser if parser else serp.links, file=outfile)
+            print(parser if parser else '', file=outfile)
 
 
 def dict_from_serp_object(serp):
     """Creates an dictionary from an SERP object."""
     keys = ('query', 'search_engine_name', 'requested_by', 'scrapemethod', 'page_number', 'requested_at', 'num_results')
-    d =  {key: getattr(serp, key) for key in keys}
+    d = {key: getattr(serp, key) for key in keys}
 
     for key, value in d.items():
         if isinstance(value, datetime.datetime):
@@ -105,9 +133,11 @@ def dict_from_scraping_object(obj):
     d['num_results'] = obj.parser.search_results['num_results']
     return d
 
-def end():
-    """Close the json array if necessary."""
-    output_format = Config['GLOBAL'].get('output_format', 'stdout')
 
-    if output_format == 'json':
-        outfile.write(']')
\ No newline at end of file
+def row2dict(obj):
+    """Convert sql alchemy object to dictionary."""
+    d = {}
+    for column in obj.__table__.columns:
+        d[column.name] = str(getattr(obj, column.name))
+
+    return d
\ No newline at end of file
